@@ -23,6 +23,7 @@ print.bench_expr <- function(x, ...) {
   NextMethod()
 }
 
+#' @export
 type_sum.bench_expr <- function(x) {
   "bch:expr"
 }
@@ -33,7 +34,7 @@ type_sum.bench_expr <- function(x) {
   new_bench_expr(new_x)
 }
 
-# @export
+# Lazily registered in `.onLoad()`
 vec_proxy.bench_expr <- function(x, ...) {
   desc <- attr(x, "description")
   attributes(x) <- NULL
@@ -41,15 +42,20 @@ vec_proxy.bench_expr <- function(x, ...) {
   vctrs::new_data_frame(out, n = length(x))
 }
 
-# @export
+# Lazily registered in `.onLoad()`
 vec_restore.bench_expr <- function(x, to, ...) {
   new_bench_expr(x$x, x$desc)
 }
 
+#' @export
 pillar_shaft.bench_expr <- function(x, ...) {
-  pillar::new_pillar_shaft_simple(format.bench_expr(x), align = "left", ...)
+  # We format bench expressions exactly like character vectors. This ensures
+  # they are truncated as needed, which is useful for long unnamed expressions
+  # (#94). This is the same logic as `pillar:::pillar_shaft.factor()`.
+  pillar_shaft(as.character(x), ...)
 }
 
+# Lazily registered in `.onLoad()`
 scale_type.bench_expr <- function(x) {
   "bench_expr"
 }
@@ -81,7 +87,11 @@ scale_y_bench_expr <- function(...) {
 #' @rdname scale_bench_expr
 #' @keywords internal
 #' @export
-scale_colour_bench_expr <- function(palette = scales::hue_pal(...), ..., aesthetics = "colour") {
+scale_colour_bench_expr <- function(
+  palette = scales::hue_pal(...),
+  ...,
+  aesthetics = "colour"
+) {
   sc <- ggplot2::discrete_scale(aesthetics, "bench_expr", palette, ...)
   sc$transform <- as.character
   sc
